@@ -22,21 +22,13 @@
 #include "xcb_framebuffer.h"
 #include <KPluginFactory>
 
-
-K_PLUGIN_FACTORY_WITH_JSON(XCBFrameBufferPluginFactory, "krfb_framebuffer_xcb.json",
-               registerPlugin<XCBFrameBufferPlugin>();)
+K_PLUGIN_CLASS(XCBFrameBufferPlugin)
 
 XCBFrameBufferPlugin::XCBFrameBufferPlugin(QObject *parent, const QVariantList &args)
     : FrameBufferPlugin(parent, args)
 {
 }
 
-
-XCBFrameBufferPlugin::~XCBFrameBufferPlugin()
-{
-}
-
-
 FrameBuffer *XCBFrameBufferPlugin::frameBuffer(WId id, const QVariantMap &args)
 {
     Q_UNUSED(args);
